@@ -1,12 +1,22 @@
 # Copyright (C) 2017-2018 Jurriaan Bremer.
 # This file is part of SFlock - http://www.sflock.org/.
 # See the file 'docs/LICENSE.txt' for copying permission.
-
+import os
 import re
 from collections import OrderedDict
 
 import pefile
 from sflock.aux.decode_vbe_jse import DecodeVBEJSE
+"""
+try:
+    import yara
+    cur_dir = os.path.dirname(os.path.abspath(__file__))
+    with open(os.path.join(cur_dir, "data", "yara", "shellcodes.yar"), "rb") as f:
+        shellcode_rules = yara.compile(sources=f.read())
+    HAVE_YARA = True
+except ImportError:
+    HAVE_YARA = False
+"""
 
 try:
     from unicorn import Uc, UC_MODE_32, UC_MODE_64, UC_ARCH_X86, UC_HOOK_CODE, unicorn
@@ -15,6 +25,10 @@ try:
 except ImportError:
     HAVE_UNICORN = False
 
+shellcode_code_base = 0x100000
+shellcode_threshold = 0x100
+shellcode_limit = 0x100000
+
 file_extensions = OrderedDict(
     [
         ("msi", (b".msi", b".msp", b".appx")),
@@ -28,7 +42,7 @@ file_extensions = OrderedDict(
         ("swf", (b".swf", b".fws")),
         ("python", (b".py", b".pyc", b".pyw")),
         ("ps1", (b".ps1",)),
-        # ("msg", (b".msg",)),
+        # ("msg", (b".msg",, b".rpmsg")),
         # ("eml", (b".eml", b".ics")),
         ("js", (b".js", b".jse")),
         ("ie", (b".html", b".url")), # b".htm",
@@ -110,6 +124,7 @@ magics = OrderedDict(
         # ("news or mail", "eml"),
         # ("saved news", "eml"),
         # ("MIME entity", "eml"),
+        # ("rpmsg Restricted Permission Message", "msg"),
         ("Java Jar archive", "jar"),
         ("META-INF/MANIFEST.MF", "jar"),
         ("Java Jar file data (zip)", "jar"),
@@ -118,12 +133,13 @@ magics = OrderedDict(
     ]
 )
 
-shellcode_code_base = 0x100000
-shellcode_threshold = 0x100
-shellcode_limit = 0x100000
-
-
 def detect_shellcode(f):
+    """
+    if HAVE_YARA:
+        matches = shellcode_rules.match(data=f.contents)
+        if matches:
+            return "Shellcode"
+    """
     global shellcode_count32, shellcode_count64, shellcode_last_address
     shellcode_count32 = 0
     shellcode_count64 = 0
